@@ -5,7 +5,7 @@
  * notice and this notice are preserved.
  */
 
-#if HAVE_CONFIG_H
+#ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
@@ -36,7 +36,7 @@ main (void)
   char buffer[MAX_BUF + 1];
   const char *err;
   gnutls_psk_client_credentials_t pskcred;
-  const gnutls_datum_t key = { "DEADBEEF", 8 };
+  const gnutls_datum_t key = { (char*) "DEADBEEF", 8 };
 
   gnutls_global_init ();
 
