@@ -539,7 +539,7 @@ handle_error (socket_st * hd, int err)
        */
     }
 
-  check_rehandshake (hd, ret);
+  check_rehandshake (hd, err);
 
   return ret;
 }
@@ -571,7 +571,7 @@ main (int argc, char **argv)
   fd_set rset;
   int maxfd;
   struct timeval tv;
-  int user_term = 0;
+  int user_term = 0, retval = 0;
   socket_st hd;
 
   set_program_name (argv[0]);
@@ -653,8 +653,6 @@ main (int argc, char **argv)
 	    printf ("*** This is a resumed session\n");
 	}
 
-
-
       if (resume != 0 && i == 0)
 	{
 
@@ -715,6 +713,7 @@ after_handshake:
 	    {
 	      fprintf (stderr, "*** Handshake has failed\n");
 	      user_term = 1;
+	      retval = 1;
 	      break;
 	    }
 	}
@@ -745,6 +744,7 @@ after_handshake:
 	    {
 	      fprintf (stderr,
 		       "*** Server has terminated the connection abnormally.\n");
+	      retval = 1;
 	      break;
 	    }
 	  else if (ret > 0)
@@ -778,6 +778,7 @@ after_handshake:
 		    {
 		      fprintf (stderr, "*** Handshake has failed\n");
 		      user_term = 1;
+		      retval = 1;
 		      break;
 		    }
 		}
@@ -834,7 +835,7 @@ after_handshake:
 
   gnutls_global_deinit ();
 
-  return 0;
+  return retval;
 }
 
 void
